'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
var import_component_identifier = void 0,
    import_react_identifier = void 0,
    export_component_identifier = void 0;

var RENDER_NAME = 'PureVisulizerRender';

function generateImport(t, lib, path) {
	path.insertBefore(t.importDeclaration([t.ImportDefaultSpecifier(t.identifier(RENDER_NAME))], t.stringLiteral(lib)));
}

function generateCallExpression(t) {
	for (var _len = arguments.length, args = Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
		args[_key - 1] = arguments[_key];
	}

	return t.CallExpression(t.Identifier(RENDER_NAME), args);
}

exports.default = {
	getSuperClassName: function getSuperClassName(t, node) {
		var superClass = node.superClass;

		var supClassName = void 0;
		if (t.isMemberExpression(superClass)) {
			supClassName = superClass.object.name + '.' + superClass.property.name;
		} else if (t.isIdentifier(superClass)) {
			supClassName = superClass.name;
		}
		if (supClassName && supClassName === import_component_identifier) {
			export_component_identifier = node.id.name;
		}
	},
	getImportIdentifiers: function getImportIdentifiers(t, specifier) {
		if (t.isImportSpecifier(specifier)) {
			import_component_identifier = specifier.imported.name;
		} else if (t.isImportDefaultSpecifier(specifier)) {
			import_react_identifier = specifier.local.name;
			import_component_identifier = specifier.local.name + '.Component';
		}
	},
	changeExportExpression: function changeExportExpression(t) {
		var lib = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'babel-plugin-react-visualizer/lib/component';
		var path = arguments[2];
		var pPath = arguments[3];
		var node = path.node;

		if (!node) return;
		if (export_component_identifier && node.name === export_component_identifier) {
			generateImport(t, lib, pPath);
			path.replaceWith(generateCallExpression(t, t.Identifier(export_component_identifier)));
			export_component_identifier = null;
			return true;
		}
	},
	changeExportIdentifier: function changeExportIdentifier(t) {
		var lib = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'babel-plugin-react-visualizer/lib/component';
		var path = arguments[2];
		var node = path.node;

		if (export_component_identifier && node.declaration.name === export_component_identifier) {
			generateImport(t, lib, path);
			node.declaration = generateCallExpression(t, t.Identifier(export_component_identifier));
			export_component_identifier = null;
			return true;
		}
	},
	changeExportClass: function changeExportClass(t) {
		var lib = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'babel-plugin-react-visualizer/lib/component';
		var path = arguments[2];
		var node = path.node;

		if (!node) return;
		if (export_component_identifier) {
			generateImport(t, lib, path);
			path.insertBefore(node.declaration);
			node.declaration = generateCallExpression(t, t.Identifier(export_component_identifier));
			export_component_identifier = null;
			return true;
		}
	}
};